==> openshift-model-config-6.3.1-sources.jar: io/fabric8/openshift/api/model/config/v1/RequestHeaderIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RequestHeaderIdentityProviderFluent<A extends RequestHeaderIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public RequestHeaderIdentityProviderFluent.CaNested<A> editCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getChallengeURL();
  public A withChallengeURL(String challengeURL);
  public Boolean hasChallengeURL();
  public A addToClientCommonNames(Integer index,String item);
  public A setToClientCommonNames(Integer index,String item);
  public A addToClientCommonNames(java.lang.String... items);
  public A addAllToClientCommonNames(Collection<String> items);
  public A removeFromClientCommonNames(java.lang.String... items);
  public A removeAllFromClientCommonNames(Collection<String> items);
  public List<String> getClientCommonNames();
  public String getClientCommonName(Integer index);
  public String getFirstClientCommonName();
  public String getLastClientCommonName();
  public String getMatchingClientCommonName(Predicate<String> predicate);
  public Boolean hasMatchingClientCommonName(Predicate<String> predicate);
  public A withClientCommonNames(List<String> clientCommonNames);
  public A withClientCommonNames(java.lang.String... clientCommonNames);
  public Boolean hasClientCommonNames();
  public A addToEmailHeaders(Integer index,String item);
  public A setToEmailHeaders(Integer index,String item);
  public A addToEmailHeaders(java.lang.String... items);
  public A addAllToEmailHeaders(Collection<String> items);
  public A removeFromEmailHeaders(java.lang.String... items);
  public A removeAllFromEmailHeaders(Collection<String> items);
  public List<String> getEmailHeaders();
  public String getEmailHeader(Integer index);
  public String getFirstEmailHeader();
  public String getLastEmailHeader();
  public String getMatchingEmailHeader(Predicate<String> predicate);
  public Boolean hasMatchingEmailHeader(Predicate<String> predicate);
  public A withEmailHeaders(List<String> emailHeaders);
  public A withEmailHeaders(java.lang.String... emailHeaders);
  public Boolean hasEmailHeaders();
  public A addToHeaders(Integer index,String item);
  public A setToHeaders(Integer index,String item);
  public A addToHeaders(java.lang.String... items);
  public A addAllToHeaders(Collection<String> items);
  public A removeFromHeaders(java.lang.String... items);
  public A removeAllFromHeaders(Collection<String> items);
  public List<String> getHeaders();
  public String getHeader(Integer index);
  public String getFirstHeader();
  public String getLastHeader();
  public String getMatchingHeader(Predicate<String> predicate);
  public Boolean hasMatchingHeader(Predicate<String> predicate);
  public A withHeaders(List<String> headers);
  public A withHeaders(java.lang.String... headers);
  public Boolean hasHeaders();
  public String getLoginURL();
  public A withLoginURL(String loginURL);
  public Boolean hasLoginURL();
  public A addToNameHeaders(Integer index,String item);
  public A setToNameHeaders(Integer index,String item);
  public A addToNameHeaders(java.lang.String... items);
  public A addAllToNameHeaders(Collection<String> items);
  public A removeFromNameHeaders(java.lang.String... items);
  public A removeAllFromNameHeaders(Collection<String> items);
  public List<String> getNameHeaders();
  public String getNameHeader(Integer index);
  public String getFirstNameHeader();
  public String getLastNameHeader();
  public String getMatchingNameHeader(Predicate<String> predicate);
  public Boolean hasMatchingNameHeader(Predicate<String> predicate);
  public A withNameHeaders(List<String> nameHeaders);
  public A withNameHeaders(java.lang.String... nameHeaders);
  public Boolean hasNameHeaders();
  public A addToPreferredUsernameHeaders(Integer index,String item);
  public A setToPreferredUsernameHeaders(Integer index,String item);
  public A addToPreferredUsernameHeaders(java.lang.String... items);
  public A addAllToPreferredUsernameHeaders(Collection<String> items);
  public A removeFromPreferredUsernameHeaders(java.lang.String... items);
  public A removeAllFromPreferredUsernameHeaders(Collection<String> items);
  public List<String> getPreferredUsernameHeaders();
  public String getPreferredUsernameHeader(Integer index);
  public String getFirstPreferredUsernameHeader();
  public String getLastPreferredUsernameHeader();
  public String getMatchingPreferredUsernameHeader(Predicate<String> predicate);
  public Boolean hasMatchingPreferredUsernameHeader(Predicate<String> predicate);
  public A withPreferredUsernameHeaders(List<String> preferredUsernameHeaders);
  public A withPreferredUsernameHeaders(java.lang.String... preferredUsernameHeaders);
  public Boolean hasPreferredUsernameHeaders();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<RequestHeaderIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/RequestHeaderIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RequestHeaderIdentityProviderFluent<A extends RequestHeaderIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public RequestHeaderIdentityProviderFluent.CaNested<A> editCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCa();
  public RequestHeaderIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getChallengeURL();
  public A withChallengeURL(String challengeURL);
  public Boolean hasChallengeURL();
  public A addToClientCommonNames(int index,String item);
  public A setToClientCommonNames(int index,String item);
  public A addToClientCommonNames(java.lang.String... items);
  public A addAllToClientCommonNames(Collection<String> items);
  public A removeFromClientCommonNames(java.lang.String... items);
  public A removeAllFromClientCommonNames(Collection<String> items);
  public List<String> getClientCommonNames();
  public String getClientCommonName(int index);
  public String getFirstClientCommonName();
  public String getLastClientCommonName();
  public String getMatchingClientCommonName(Predicate<String> predicate);
  public Boolean hasMatchingClientCommonName(Predicate<String> predicate);
  public A withClientCommonNames(List<String> clientCommonNames);
  public A withClientCommonNames(java.lang.String... clientCommonNames);
  public Boolean hasClientCommonNames();
  public A addToEmailHeaders(int index,String item);
  public A setToEmailHeaders(int index,String item);
  public A addToEmailHeaders(java.lang.String... items);
  public A addAllToEmailHeaders(Collection<String> items);
  public A removeFromEmailHeaders(java.lang.String... items);
  public A removeAllFromEmailHeaders(Collection<String> items);
  public List<String> getEmailHeaders();
  public String getEmailHeader(int index);
  public String getFirstEmailHeader();
  public String getLastEmailHeader();
  public String getMatchingEmailHeader(Predicate<String> predicate);
  public Boolean hasMatchingEmailHeader(Predicate<String> predicate);
  public A withEmailHeaders(List<String> emailHeaders);
  public A withEmailHeaders(java.lang.String... emailHeaders);
  public Boolean hasEmailHeaders();
  public A addToHeaders(int index,String item);
  public A setToHeaders(int index,String item);
  public A addToHeaders(java.lang.String... items);
  public A addAllToHeaders(Collection<String> items);
  public A removeFromHeaders(java.lang.String... items);
  public A removeAllFromHeaders(Collection<String> items);
  public List<String> getHeaders();
  public String getHeader(int index);
  public String getFirstHeader();
  public String getLastHeader();
  public String getMatchingHeader(Predicate<String> predicate);
  public Boolean hasMatchingHeader(Predicate<String> predicate);
  public A withHeaders(List<String> headers);
  public A withHeaders(java.lang.String... headers);
  public Boolean hasHeaders();
  public String getLoginURL();
  public A withLoginURL(String loginURL);
  public Boolean hasLoginURL();
  public A addToNameHeaders(int index,String item);
  public A setToNameHeaders(int index,String item);
  public A addToNameHeaders(java.lang.String... items);
  public A addAllToNameHeaders(Collection<String> items);
  public A removeFromNameHeaders(java.lang.String... items);
  public A removeAllFromNameHeaders(Collection<String> items);
  public List<String> getNameHeaders();
  public String getNameHeader(int index);
  public String getFirstNameHeader();
  public String getLastNameHeader();
  public String getMatchingNameHeader(Predicate<String> predicate);
  public Boolean hasMatchingNameHeader(Predicate<String> predicate);
  public A withNameHeaders(List<String> nameHeaders);
  public A withNameHeaders(java.lang.String... nameHeaders);
  public Boolean hasNameHeaders();
  public A addToPreferredUsernameHeaders(int index,String item);
  public A setToPreferredUsernameHeaders(int index,String item);
  public A addToPreferredUsernameHeaders(java.lang.String... items);
  public A addAllToPreferredUsernameHeaders(Collection<String> items);
  public A removeFromPreferredUsernameHeaders(java.lang.String... items);
  public A removeAllFromPreferredUsernameHeaders(Collection<String> items);
  public List<String> getPreferredUsernameHeaders();
  public String getPreferredUsernameHeader(int index);
  public String getFirstPreferredUsernameHeader();
  public String getLastPreferredUsernameHeader();
  public String getMatchingPreferredUsernameHeader(Predicate<String> predicate);
  public Boolean hasMatchingPreferredUsernameHeader(Predicate<String> predicate);
  public A withPreferredUsernameHeaders(List<String> preferredUsernameHeaders);
  public A withPreferredUsernameHeaders(java.lang.String... preferredUsernameHeaders);
  public Boolean hasPreferredUsernameHeaders();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<RequestHeaderIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  
}
